import { onUnmounted, ref } from 'vue'

export default function useFullscreen(id: string) {
  const isFullScreen = ref<boolean>(false)

  const enterFullscreen = () => {
    const element: HTMLElement = document.getElementById(id)
    if (element) {
      // 保持原来样式
      element.dataset.originalStyle = element.getAttribute('style') || ''

      // 设置新样式
      element.style.position = 'fixed'
      element.style.top = '0'
      element.style.left = '0'
      element.style.width = '100vw'
      element.style.height = '100vh'
      element.style.zIndex = '99'
      element.style.background = '#fff'

      isFullScreen.value = true
    }
  }

  const exitFullscreen = () => {
    const element: HTMLElement = document.getElementById(id)
    if (element) {
      element.setAttribute('style', element.dataset.originalStyle || '')
      isFullScreen.value = false
    }
  }

  onUnmounted(() => {
    exitFullscreen()
  })

  return { isFullScreen, enterFullscreen, exitFullscreen }
}
