import App from './App.vue'
import router from './router'
// 路由拦截
import './router/permission'
import { setupStore } from '@/store'
import ElementPlus from 'element-plus'
import zhCn from 'element-plus/es/locale/lang/zh-cn'
import { getServerConfig } from './config'
import { createApp, Directive } from 'vue'
import { MotionPlugin } from '@vueuse/motion'
// import { useEcharts } from "@/plugins/echarts";
import { injectResponsiveStorage } from '@/utils/responsive'

import Table from '@pureadmin/table'
// import PureDescriptions from "@pureadmin/descriptions";

// 引入重置样式
import './style/reset.scss'
// 导入公共样式
import './style/index.scss'
// 一定要在main.ts中导入tailwind.css，防止vite每次hmr都会请求src/style/index.scss整体css文件导致热更新慢的问题
import './style/tailwind.css'
import 'element-plus/dist/index.css'

// 导入字体图标
import './assets/iconfont/iconfont.js'
import './assets/iconfont/iconfont.css'

// 全局组件
import globalComponent from './components/index'

// element-plus icons
import * as ElementPlusIconsVue from '@element-plus/icons-vue'

const app = createApp(App)

// 自定义指令
import * as directives from '@/directives'
Object.keys(directives).forEach((key) => {
  app.directive(key, (directives as { [key: string]: Directive })[key])
})

// 全局注册vue-tippy
import "tippy.js/dist/tippy.css";
import "tippy.js/themes/light.css";
import VueTippy from "vue-tippy";
app.use(VueTippy);

getServerConfig(app).then(async (config) => {
  app.use(router)
  await router.isReady()
  injectResponsiveStorage(app, config)
  setupStore(app)
  app.use(MotionPlugin).use(ElementPlus, { size: 'default', locale: zhCn })
  // .use(useEcharts);
  app.use(Table)
  // .use(PureDescriptions);
  app.mount('#app')
})

for (const componentItme in globalComponent) {
  app.component(componentItme, globalComponent[componentItme])
}

for (const [key, component] of Object.entries(ElementPlusIconsVue)) {
  app.component(key, component)
}
