import { KeepAlive } from "vue";

const Layout = () => import("@/layout/index.vue");

export default {
  path: '/dataSource',
  componnet: Layout,
  name: 'DataSource',
  redirect: '/dataSource/receiveLendingLedger',
  meta: {
    title: '数据源',
    icon: 'system'
  },
  children: [
    {
      path: '/financialReport',
      name: 'FinancialReport',
      component: () => import('@/views/dataSource/financialStatement/index.vue'),
      meta: {
        title: '财务报表',
        showParent: true
      },
      children: [
        {
          path: '/financialReport/financialReportAdd',
          name: 'FinancialReportAdd',
          component: () => import('@/views/dataSource/financialStatement/Add.vue'),
          meta: {
            title: '新增财务报表',
            activePath: '/financialReport',
            showLink: false
          },
        },
        {
          path: '/financialReport/financialReportDetail',
          name: 'FinancialReportDetail',
          component: () => import('@/views/dataSource/financialStatement/Detail.vue'),
          meta: {
            title: '财务报表查看',
            activePath: '/financialReport',
            showLink: false
          },
        }
      ]
    },
    {
      path: '/annualSetting',
      name: 'AnnualSetting',
      component: () => import('@/views/dataSource/annualSetting/index.vue'),
      meta: {
        title: '年度设定'
      },
      children: [
        {
          path: '/annualSetting/annualGoalAdd',
          name: 'AnnualGoalAdd',
          component: () => import('@/views/dataSource/annualSetting/annualGoalAdd.vue'),
          meta: {
            title: '年度目标新增',
            showParent: true,
            activePath: '/annualSetting',
            showLink: false
          },
        },
        {
          path: '/annualSetting/annualGoalDetail',
          name: 'AnnualGoalDetail',
          component: () => import('@/views/dataSource/annualSetting/annualGoalDetail.vue'),
          meta: {
            title: '年度目标查看',
            showParent: true,
            activePath: '/annualSetting',
            showLink: false
          },
        },
        {
          path: '/annualSetting/annualBudgetAdd',
          name: 'AnnualBudgetAdd',
          component: () => import('@/views/dataSource/annualSetting/annualBudgetAdd.vue'),
          meta: {
            title: '公司预算新增',
            showParent: true,
            activePath: '/annualSetting',
            showLink: false
          },
        },
        {
          path: '/annualSetting/annualBudgetDetail',
          name: 'AnnualBudgetDetail',
          component: () => import('@/views/dataSource/annualSetting/annualBudgetDetail.vue'),
          meta: {
            title: '公司预算查看',
            showParent: true,
            activePath: '/annualSetting',
            showLink: false
          },
        },
        {
          path: '/annualSetting/annualBudgetPartAdd',
          name: 'AnnualBudgetPartAdd',
          component: () => import('@/views/dataSource/annualSetting/annualBudgetPartAdd.vue'),
          meta: {
            title: '部门预算新增',
            showParent: true,
            activePath: '/annualSetting',
            showLink: false
          },
        },
        {
          path: '/annualSetting/annualBudgetPartDetail',
          name: 'AnnualBudgetPartDetail',
          component: () => import('@/views/dataSource/annualSetting/annualBudgetPartDetail.vue'),
          meta: {
            title: '部门预算查看',
            showParent: true,
            activePath: '/annualSetting',
            showLink: false
          },
        },
      ]
    },
    {
      path: '/receiveLendingLedger',
      name: 'ReceiveLendingLedger',
      component: () => import('@/views/dataSource/receiveLendingLedger/index.vue'),
      meta: {
        title: '收放款台账',
        keepAlive: true,
      },
      children: [
        {
          path: '/financeEdit',
          name: 'FinanceEdit',
          component: () => import('@/views/dataSource/receiveLendingLedger/financeEdit.vue'),
          meta: {
            title: '财务修正',
            showLink: false,
            activePath: '/receiveLendingLedger',
            keepAlive: true,
          },
        },
        {
          path: '/refinanceEdit',
          name: 'RefinanceEdit',
          component: () => import('@/views/dataSource/receiveLendingLedger/refinanceEdit.vue'),
          meta: {
            title: '再融资修正',
            showLink: false,
            activePath: '/receiveLendingLedger'
          },
        },
        {
          path: '/receiveLendingLedgerSee',
          name: 'ReceiveLendingLedgerSee',
          component: () => import('@/views/dataSource/receiveLendingLedger/see.vue'),
          meta: {
            title: '收放款台账明细',
            showLink: false,
            activePath: '/receiveLendingLedger'
          },
        },
          {
          path: '/receiveLendingLedgerOtherSee',
          name: 'ReceiveLendingLedgerOtherSee',
          component: () => import('@/views/dataSource/receiveLendingLedger/otherSee.vue'),
          meta: {
            title: '收放款台账明细',
            showLink: false,
            activePath: '/receiveLendingLedger'
          },
        }
      ]
    },
    {
      path: '/businessLedger',
      name: 'BusinessLedger',
      component: () => import('@/views/dataSource/businessLedger/index.vue'),
      meta: {
        title: '业务台账'
      },
      children: [
        {
          path: '/businessLedgerDetails',
          name: 'BusinessLedgerDetails',
          component: () => import('@/views/dataSource/businessLedger/details.vue'),
          meta: {
            title: '业务台账明细',
            showLink: false,
            activePath: '/businessLedger'
          },
        }
      ]
    },
    {
      path: '/customerLedger',
      name: 'CustomerLedger',
      component: () => import('@/views/dataSource/customerLedger/index.vue'),
      meta: {
        title: '客户台账'
      },
      children: [
        {
          path: '/customerLedgerDetails',
          name: 'CustomerLedgerDetails',
          component: () => import('@/views/dataSource/customerLedger/details.vue'),
          meta: {
            title: '客户台账明细',
            showLink: false,
            activePath: '/customerLedger'
          },
        }
      ]
    },
    {
      path: '/assetDataManage',
      name: 'AssetDataManage',
      component: () => import('@/views/dataSource/assetDataManage/index.vue'),
      meta: {
        title: '资管数据管理'
      },
      children: [
        {
          path: '/customerLedgerDetails',
          name: 'CustomerLedgerDetails',
          component: () => import('@/views/dataSource/customerLedger/details.vue'),
          meta: {
            title: '客户台账明细',
            showLink: false,
            activePath: '/customerLedger'
          },
        }
      ]
    },
    {
      path: '/m3Manage',
      name: 'M3IncomeManage',
      component: () => import('@/views/dataSource/m3Manage/index.vue'),
      meta: {
        title: 'M3收入管理'
      },
      children: [
        {
          path: '/m3Manage/m3ManageAdd',
          name: 'M3ManageAdd',
          component: () => import('@/views/dataSource/m3Manage/Add.vue'),
          meta: {
            title: '新增M3收入',
            activePath: '/m3Manage',
            showLink: false
          },
        },
      ]
    },
    {
      path: '/chargeManage',
      name: 'FeeManage',
      component: () => import('@/views/dataSource/chargeManage/index.vue'),
      meta: {
        title: '费用管理'
      },
      children: [
        {
          path: '/chargeManage/chargeManageAdd',
          name: 'ChargeManageAdd',
          component: () => import('@/views/dataSource/chargeManage/Add.vue'),
          meta: {
            title: '新增费用管理',
            showParent: true,
            activePath: '/chargeManage',
            showLink: false
          },
        },
        {
          path: '/chargeManage/chargeManageEdit',
          name: 'ChargeManageEdit',
          component: () => import('@/views/dataSource/chargeManage/Edit.vue'),
          meta: {
            title: '费用管理编辑',
            showParent: true,
            activePath: '/chargeManage',
            showLink: false
          },
        },
        {
          path: '/chargeManage/chargeManageDetail',
          name: 'ChargeManageDetail',
          component: () => import('@/views/dataSource/chargeManage/Detail.vue'),
          meta: {
            title: '费用管理详情',
            showParent: true,
            activePath: '/chargeManage',
            showLink: false
          },
        }
      ]
    },
    {
      path: '/costManage',
      name: 'CostManage',
      component: () => import('@/views/dataSource/costManage/index.vue'),
      meta: {
        title: '成本管理'
      },
      children: [
        {
          path: '/costManage/costManageAdd',
          name: 'CostManageAdd',
          component: () => import('@/views/dataSource/costManage/IndirectCostAdd.vue'),
          meta: {
            title: '成本管理新增',
            showParent: true,
            activePath: '/costManage',
            showLink: false
          },
        }
      ]
    },
    {
      path: '/assesmentManage',
      name: 'AssesmentManage',
      redirect: '/assesmentTarget',
      meta: {
        title: '考核数据管理'
      },
      children: [
        {
          path: '/assesmentTarget',
          name: 'AssesmentTarget',
          component: () => import('@/views/dataSource/assesmentManage/targetSetting.vue'),
          meta: {
            title: '考核目标设定',
            showParent: true,
            activePath: '/assesmentTarget',
          }
        },
        {
          path: '/assesmentTargetAdd',
          name: 'AssesmentTargetAdd',
          component: () => import('@/views/dataSource/assesmentManage/targetSettingAdd.vue'),
          meta: {
            title: '考核目标设定新增',
            showLink: false,
            activePath: '/assesmentTarget',
          }
        },
        {
          path: '/assesmentTargetDetail',
          name: 'AssesmentTargetDetail',
          component: () => import('@/views/dataSource/assesmentManage/targetSettingDetail.vue'),
          meta: {
            title: '考核目标设定查看',
            showLink: false,
            activePath: '/assesmentTarget',
          }
        },
        {
          path: '/profitLoss',
          name: 'ProfitLoss',
          component: () => import('@/views/dataSource/assesmentManage/profitLoss.vue'),
          meta: {
            title: '人员盈亏平衡',
            showParent: true,
            activePath: '/profitLoss',
          }
        },
        {
          path: '/profitLossAdd',
          name: 'ProfitLossAdd',
          component: () => import('@/views/dataSource/assesmentManage/profitLossAdd.vue'),
          meta: {
            title: '人员盈亏平衡新增',
            showLink: false,
            activePath: '/profitLoss',
          }
        },
        {
          path: '/profitLossDetail',
          name: 'ProfitLossDetail',
          component: () => import('@/views/dataSource/assesmentManage/profitLossDetail.vue'),
          meta: {
            title: '人员盈亏平衡查看',
            showLink: false,
            activePath: '/profitLoss',
          }
        },
        {
          path: '/complete',
          name: 'Complete',
          component: () => import('@/views/dataSource/assesmentManage/complete.vue'),
          meta: {
            title: '人员考核完成',
            showParent: true,
            activePath: '/complete',
          }
        },
        {
          path: '/completeAdd',
          name: 'CompleteAdd',
          component: () => import('@/views/dataSource/assesmentManage/completeAdd.vue'),
          meta: {
            title: '人员考核完成新增',
            showLink: false,
            activePath: '/complete',
          }
        },
        {
          path: '/salary',
          name: 'Salary',
          component: () => import('@/views/dataSource/assesmentManage/salary.vue'),
          meta: {
            title: '部门工资薪资',
            showParent: true,
            activePath: '/salary',
          }
        }
      ]
    },
     {
      path: '/investmentManage',
      name: 'InvestmentManage',
      component: () => import('@/views/dataSource/investmentManage/index.vue'),
      meta: {
        title: '跟投管理'
      },
      children: [
        {
          path: '/investmentManageDetails',
          name: 'InvestmentManageDetails',
          component: () => import('@/views/dataSource/investmentManage/details.vue'),
          meta: {
            title: '跟投管理明细',
            showLink: false,
            activePath: '/investmentManage'
          },
        }
      ]
    },
    {
      path: '/capitalPlanDetail',
      name: 'CapitalPlanDetail',
      component: () => import('@/views/dataSource/capitalPlanDetail/index.vue'),
      meta: {
        title: '资金收/支计划明细'
      },
    }
  ]
}
