import { router } from './index'
import { getConfig } from '@/config'
import NProgress from '@/utils/progress'
import { useMultiTagsStoreHook } from '@/store/modules/multiTags'
import { usePermissionStoreHook } from '@/store/modules/permission'
import { useUserStoreHook } from '@/store/modules/user'

import {
  initRouter,
  getTopMenu,
  isOneOfArray,
  findRouteByPath,
  handleAliveRoute,
  addPathMatch
} from './utils'

import { type Router } from 'vue-router'

import { getToken } from '@/utils/auth'

import { isUrl, openLink, isAllEmpty } from '@pureadmin/utils'

/** 路由白名单 */
const whiteList = ['/login']

const { VITE_HIDE_HOME } = import.meta.env

router.beforeEach(async (to: ToRouteType, _from, next) => {
  if (to.meta?.keepAlive) {
    handleAliveRoute(to, 'add')
    // 页面整体刷新和点击标签页刷新
    if (_from.name === undefined || _from.name === 'Redirect') {
      handleAliveRoute(to)
    }
  }
  const token = getToken()
  NProgress.start()
  const externalLink = isUrl(to?.name as string)
  if (!externalLink) {
    to.matched.some((item) => {
      if (!item.meta.title) return ''
      const Title = getConfig().Title
      if (Title) document.title = `${item.meta.title} | ${Title}`
      else document.title = item.meta.title as string
    })
  }
  /** 如果已经登录并存在登录信息后不能跳转到路由白名单，而是继续保持在当前页面 */
  function toCorrectRoute() {
    whiteList.includes(to.fullPath) ? next(_from.fullPath) : next()
  }
  if (token) {
    // 开启隐藏首页后在浏览器地址栏手动输入首页welcome路由则跳转到404页面
    if (VITE_HIDE_HOME === 'true' && to.fullPath === '/welcome') {
      next({ path: '/error/404' })
    }
    // name为超链接
    if (externalLink) {
      openLink(to?.name as string)
      NProgress.done()
    } else {
      // 刷新
      if (
        usePermissionStoreHook().wholeMenus.length === 0 &&
        to.path !== '/login'
      ) {
        await useUserStoreHook().getUserInfo()
        await initRouter().then((router: Router) => {
          if (!useMultiTagsStoreHook().getMultiTagsCache) {
            const { path } = to
            const route = findRouteByPath(
              path,
              router.options.routes[0].children
            )
            getTopMenu(true)
            // query、params模式路由传参数的标签页不在此处处理
            if (route && route.meta?.title) {
              if (isAllEmpty(route.parentId) && route.meta?.backstage) {
                // 此处为动态顶级路由（目录）
                const { path, name, meta } = route.children[0]
                useMultiTagsStoreHook().handleTags('push', {
                  path,
                  name,
                  meta
                })
              } else {
                const { path, name, meta } = route
                useMultiTagsStoreHook().handleTags('push', {
                  path,
                  name,
                  meta
                })
              }
            }
          }
          // 确保动态路由完全加入路由列表并且不影响静态路由（注意：动态路由刷新时router.beforeEach可能会触发两次，第一次触发动态路由还未完全添加，第二次动态路由才完全添加到路由列表，如果需要在router.beforeEach做一些判断可以在to.name存在的条件下去判断，这样就只会触发一次）
          if (isAllEmpty(to.name)) router.push(to.fullPath)
        })
      }
      toCorrectRoute()
    }
  } else {
    if (to.path !== '/login') {
      if (whiteList.indexOf(to.path) !== -1) {
        next()
      } else {
        next({ path: '/login' })
      }
    } else {
      next()
    }
  }
})

router.afterEach(() => {
  NProgress.done()
})
