import { defineStore } from "pinia";
import { store } from "@/store";
import { userType } from "./types";
import { routerArrays } from "@/layout/types";
import { router, resetRouter } from "@/router";
import { getLogin, getUserInfo, getPermission } from "@/api/user";
import { useMultiTagsStoreHook } from "@/store/modules/multiTags";
import { setToken, removeToken, setSessionStorage } from "@/utils/auth";


const filterRoutes = (route, menus) => {
  route.forEach(item => {
    if (menus.includes(item.name)) {
      item.hidden = false
    } else {
      item.hidden = true
    }
    if (item.children && item.children?.length) {
      filterRoutes(item.children, menus)
    }
  })
}

export const useUserStore = defineStore({
  id: "pure-user",
  state: (): userType => ({
    userInfo: {},
    // 用户名
    username: ''
  }),
  // getters: {
  //   username: state => state.username
  // },
  actions: {
    /** 登入 */
    async loginByUsername(data) {
      return new Promise((resolve, reject) => {
        getLogin(data)
          .then(({ data }) => {
            setToken(data.token);
            resolve(data);
          })
          .catch(error => {
            reject(error);
          });
      });
    },

    /** 获取用户信息 */
    async getUserInfo() {
      return new Promise<void>((resolve, reject) => {
        getUserInfo().then(({ data }) => {
          this.userInfo = data
          this.username = data.name
          resolve(data)
        }).catch(() => {
          reject()
        })
      })
    },

    // 获取用户权限
    getPermission(): any {
      return new Promise<void>((resolve, reject) => {
        getPermission().then(({ data }) => {
          resolve(data)
        })
      })
    },

    /** 前端登出（不调用接口） */
    logOut() {
      this.username = "";
      this.roles = [];
      removeToken();
      useMultiTagsStoreHook().handleTags("equal", [...routerArrays]);
      resetRouter();
      router.push("/login");
    },
  }
});

export function useUserStoreHook() {
  return useUserStore(store);
}
