import Cookies from "js-cookie";

export interface DataInfo<T> {
  /** token */
  accessToken: string;
  /** `accessToken`的过期时间（时间戳） */
  expires: T;
  /** 用于调用刷新accessToken的接口时所需的token */
  refreshToken: string;
  /** 用户名 */
  username?: string;
  /** 当前登陆用户的角色 */
  roles?: Array<string>;
}

export const sessionKey = "user-info";
export const TokenKey = "BI-token";

/** 获取`token` */
export function getToken(): string {
  // 此处与`TokenKey`相同，此写法解决初始化时`Cookies`中不存在`TokenKey`报错
  return Cookies.get(TokenKey)
}
export function setToken(token: string) {
  Cookies.set(TokenKey, token)
}

/** 删除`token`以及key值为`user-info`的session信息 */
export function removeToken() {
  Cookies.remove(TokenKey);
}

/** 格式化token（jwt格式） */
export const formatToken = (token: string): string => {
  return "Bearer " + token;
}

export function getSessionStorage(name) {
  return sessionStorage.getItem(name)
}

export function setSessionStorage(name, value) {
  return sessionStorage.setItem(name, value)
}

export function removeSessionStorage(name) {
  return sessionStorage.removeItem(name)
}
