import { ref } from 'vue'
import { useDictStore } from '@/store/modules/dict'
import { router } from '@/router/index'
import { getSessionStorage } from '@/utils/auth'

const powerList = getSessionStorage('buttons') || []

const tablePower = (item?, tab?, row?) => {
    const { tabPower, rowPower, power, satausPower } = item
    if (power && !powerList.includes(power)) {
      return false
    }
    // if (rowPower && (!row.taskName || !rowPower.includes(row.taskName))) {
    //   return false
    // }
    if (satausPower && (!satausPower.includes(row.buttonFlag))) {
      return false
    }
    // if (tabPower && !tabPower.includes(tab)) {
    //   return false
    // }
    return true
  }

export function useColumns(parentFn?:(edit: boolean, rows: any) => void) {
  const columns: TableColumnList = [
    {
      type: 'selection',
      width: 50,
      selectable: (row, index) => row.reportName !== 2
    },
    {
      label: '序号',
      type: 'index',
      width: 100
    },
    {
      label: '年度',
      prop: 'reportYear',
      showOverflowTooltip: true
    },
    {
      label: '报表类型',
      prop: 'reportType',
      showOverflowTooltip: true
    },
    {
    label: "操作",
      cellRenderer: ({ index, row }) => {
        const btnList = [
          {
            msg: '查看',
            category: 'see',
            power: 'viewAnnualSetting'
          },
          {
            msg: '修改',
            category: 'edit',
            power: 'updateAnnualSetting'
          },
        ]
        const options = btnList.map(item => {
          return tablePower(item, '', row) && (
            <el-tooltip class='item' effect='dark' content={item.msg} placement='top' >
                <span class='table-icon-box' onClick={() => { handleOperate(item.category, row) }}>
                  {/* class={item.icon} */}
                {/* <i onClick={() => { this.handleOperate(item.category, row) }}></i> */}
                {item.msg}
              </span>
            </el-tooltip>
          )
        })
        return (
          <>
            <div>{ options }</div>
          </>
        )
      }
    }
  ]

  const handleOperate = (operateType, row) => {
    if (operateType == 'edit') {
      handleEdit(row)
    }
    if (operateType == 'see') {
      handleWatch(row)
    }
  }

  const handleWatch = (rows?) => {
    router.push({
      name: 'AnnualGoalDetail',
      query: {
        type: 'see',
        id: rows.id
      }
    })
   }

  const handleEdit = (rows?: any) => {
    router.push({
      name: 'AnnualGoalAdd',
      query: {
        type: 'edit',
        id: rows.id
      }
    })
  }


  const tableData = ref<any[]>([])
  const total = ref<number>(0)

  return {
    columns,
    tableData,
    total
  }
}
