import { ref } from "vue"
import { findUserByOrgId } from "@/api/dataSource/m3Manage"

export function usePartColums(departmentList?: any[], feildsDisabled?: boolean) {
  const tablePartData = ref<any[]>([
    {
      orgId: '',
      ta1: '',
      ta2: ''
    }
  ])

  const partColumns: TableColumnList = [
    {
      headerRenderer: () => {
        return (
          <>
            <span>姓名 <span style='color: red'>*</span></span>
          </>
        )
      },
      cellRenderer: ({ row }) => {
        return (
          <>
            <el-select v-model={row.orgId} disabled={ feildsDisabled }>
              {
                departmentList.map(org => (
                  <el-option key={org.internalCode} label={org.name} value={org.internalCode} />
                ))
              }
            </el-select>
          </>
        )
      }
    },
    {
      headerRenderer: () => {
        return (
          <>
            <span>考核利润指标（TA1） <span style='color: red'>*</span></span>
          </>
        )
      },
      cellRenderer: ({ row }) => {
        return (
          <>
            <cy-amount-input v-model={ row.ta1 } disabled={ feildsDisabled }></cy-amount-input>
          </>
        )
      }
    },
    {
      headerRenderer: () => {
        return (
          <>
            <span>再融资指标（TA2） <span style='color: red'>*</span></span>
          </>
        )
      },
      cellRenderer: ({ row }) => {
        return (
          <>
            <cy-amount-input v-model={ row.ta2 } disabled={ feildsDisabled }></cy-amount-input>
          </>
        )
      }
    },
    {
      label: '操作',
      cellRenderer: ({ index }) => {
        return (
          <>
            <span class='cursor-pointer text-[#6355FF] mr-[10px]' onClick={() => { addPart() }}>添加</span>
            { index !== 0 && tablePartData.value.length  > 1 ? <span class='cursor-pointer text-[#6355FF]' onClick={() => { delPart(index) }  }>删除</span> : '' }

          </>
        )
      }
    }
  ]

  const addPart = () => {
    tablePartData.value.push({
      orgId: '',
      ta1: '',
      ta2: ''
    })
  }

  const delPart = (idx) => {
    tablePartData.value.splice(idx, 1)
  }

  return {
    tablePartData,
    partColumns
  }
}

const personNameList = ref<any[]>([])

export const queryPersonList = async (partId?: string | number) => {
  if (partId) {
    const res: AxiosResponseRes = await findUserByOrgId({ orgId: partId })
    personNameList.value = res.data
  }
}

export function usePersonColums(feildsDisabled?: boolean) {
  const tablePersonData = ref<any[]>([
    {
      userId: '',
      ta1: '',
      ta2: ''
    }
  ])

  const personColumns: TableColumnList = [
    {
      headerRenderer: () => {
        return (
          <>
            <span>姓名 <span style='color: red'>*</span></span>
          </>
        )
      },
      cellRenderer: ({ row }) => {
        return (
          <>
            <el-select v-model={row.userId} disabled={ feildsDisabled }>
              {
                personNameList.value.map(org => (
                  <el-option key={org.internalCode} label={org.name} value={org.internalCode} />
                ))
              }
            </el-select>
          </>
        )
      }
    },
    {
      headerRenderer: () => {
        return (
          <>
            <span>考核利润指标（TA1） <span style='color: red'>*</span></span>
          </>
        )
      },
      cellRenderer: ({ row }) => {
        return (
          <>
            <cy-amount-input v-model={ row.ta1 } disabled={ feildsDisabled }></cy-amount-input>
          </>
        )
      }
    },
    {
      headerRenderer: () => {
        return (
          <>
            <span>再融资指标（TA2） <span style='color: red'>*</span></span>
          </>
        )
      },
      cellRenderer: ({ row }) => {
        return (
          <>
            <cy-amount-input v-model={ row.ta2 } disabled={ feildsDisabled }></cy-amount-input>
          </>
        )
      }
    },
    {
      label: '操作',
      cellRenderer: ({ index }) => {
        return (
          <>
            <span class='cursor-pointer text-[#6355FF] mr-[10px]' onClick={() => { addPerson() }}>添加</span>
            { index !== 0 && tablePersonData.value.length  > 1 ? <span class='cursor-pointer text-[#6355FF]' onClick={() => { delPerson(index) }  }>删除</span> : '' }

          </>
        )
      }
    }
  ]

  const addPerson = () => {
    tablePersonData.value.push({
      userId: '',
      ta1: '',
      ta2: ''
    })
  }

  const delPerson = (idx) => {
    tablePersonData.value.splice(idx, 1)
  }

  return {
    tablePersonData,
    personColumns,
    queryPersonList
  }
}
