import { ref } from 'vue'
import { router } from '@/router/index'
import { exportFile } from '@/utils'
import { getSessionStorage } from '@/utils/auth'

const powerList = getSessionStorage('buttons') || []

const tablePower = (item?, tab?, row?) => {
    const { tabPower, rowPower, power, satausPower } = item
    if (power && !powerList.includes(power)) {
      return false
    }
    // if (rowPower && (!row.taskName || !rowPower.includes(row.taskName))) {
    //   return false
    // }
    if (satausPower && (!satausPower.includes(row.buttonFlag))) {
      return false
    }
    // if (tabPower && !tabPower.includes(tab)) {
    //   return false
    // }
    return true
  }

export function useTargetColumns(parentFn?:(rows?: any) => void) {
  const columns: TableColumnList = [
    {
      label: '序号',
      type: 'index',
      width: 100
    },
    {
      label: '月度',
      prop: 'date',
      showOverflowTooltip: true
    },
    {
      label: '表单类型',
      prop: 'formType',
      showOverflowTooltip: true
    },
    {
      label: '考核维度',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => {
        return (
          <>
            <span v-if={ row.checkDimensio !== null }>{ row.checkDimension == 0 ? '人员' : '部门' }</span>
          </>
        )
      }
    },
    {
      label: '最近更新时间',
      prop: 'gmtModified',
      showOverflowTooltip: true
    },
    {
    label: "操作",
      cellRenderer: ({ index, row }) => {
        const btnList = [
          {
            msg: '查看',
            category: 'see',
            icon: 'text-customPurple iconfont icon-watch',
            // power: 'viewFee'
          },
          {
            msg: '修改',
            category: 'edit',
            icon: 'text-customPurple iconfont icon-edit',
            // power: 'updateFee'
          }
        ]
        const options = btnList.map(item => {
          return tablePower(item, '', row) && (
            <el-tooltip class='item' effect='dark' content={item.msg} placement='top' >
                <span class='table-icon-box'>
                <i class={item.icon} onClick={() => { handleOperate(item.category, row) }}></i>
              </span>
            </el-tooltip>
          )
        })
        return (
          <>
            <div>{ options }</div>
          </>
        )
      }
    }
  ]

  const handleOperate = (operateType, row) => {
    if (operateType == 'edit') {
      handleEdit(row)
    }
    if (operateType == 'see') {
      handleWatch(row)
    }
  }

  const handleWatch = (rows?) => {
    router.push({
      name: 'AnnualBudgetDetail',
      query: {
        type: 'see',
        id: rows.id
      }
    })
   }

  const handleEdit = (rows?: any) => {
    router.push({
      name: 'AnnualBudgetAdd',
      query: {
        type: 'edit',
        id: rows.id
      }
    })
  }

  const tableData = ref<any[]>([])
  const total = ref<number>(0)

  return {
    columns,
    tableData,
    total,
    handleEdit
  }
}
