import { ref, computed } from 'vue'
import { useRouter } from 'vue-router'
import { ElMessageBox } from 'element-plus'
import { message } from '@utils/message'
import { forMatMoney, parseTime } from '@utils'
import { deleteAumTable } from '@api/assetDataManage'

export function useColumns(dialogStatus, ruleForm, fetchData) {
  const router = useRouter()
  const columns: TableColumnList = [
    // {
    //   type: 'selection',
    // },
    {
      label: '序号',
      type: 'index',
      width: 55
    },

    {
      label: '所属部门',
      prop: 'orgName',
      showOverflowTooltip: true
    },
    {
      label: '项目名称',
      prop: 'projectNameStr',
      showOverflowTooltip: true
    },
    {
      label: '资产类型',
      prop: 'assetType',
      showOverflowTooltip: true
    },
    {
      label: '产品类型',
      prop: 'productType',
      showOverflowTooltip: true
    },
    {
      label: '当月投放（元）',
      prop: 'currentMonthInvest',
      showOverflowTooltip: true,
      width: 130,
      cellRenderer: ({ row }) => {
        return forMatMoney(row.currentMonthInvest)
      }
    },
    {
      label: '垫付（元）',
      prop: 'advancePayment',
      showOverflowTooltip: true,
      cellRenderer: ({ row }) => {
        return forMatMoney(row.advancePayment)
      }
    },
    {
      label: '累计（元）',
      prop: 'cumulative',
      showOverflowTooltip: true,
      cellRenderer: ({ row }) => {
        return forMatMoney(row.cumulative)
      }
    },
    {
      label: '待还本金（元）',
      prop: 'pendingPrincipal',
      showOverflowTooltip: true,
      width: 130,
      cellRenderer: ({ row }) => {
        return forMatMoney(row.pendingPrincipal)
      }
    },
    {
      label: '月份',
      prop: 'month',
      showOverflowTooltip: true,
      cellRenderer: ({ row }) => {
        return parseTime(`${row.month} 00:00:00`, 'y-m')
      }
    },
    {
      label: '操作',
      width: '160',
      cellRenderer: ({ index, row }) => {
        const btnList = [
          {
            msg: '修改',
            icon: 'text-customPurple iconfont icon-edit',
            power: 'updateAUMAsset',
            tabPower: [],
            category: 'edit'
          },
          {
            msg: '删除',
            icon: 'text-customPurple iconfont icon-shanchu',
            power: 'deleteAUMAsset',
            tabPower: [],
            category: 'delete'
          }
        ]
        const options = btnList.map((item) => {
          return (
            <el-tooltip effect="dark" content={item.msg} placement="top">
              <i
                class={item.icon}
                v-power={item.power}
                onClick={() => {
                  handlerOperate(item.category, row)
                }}></i>
            </el-tooltip>
          )
        })
        return <>{options}</>
      }
    }
  ]

  const tablePower = ({ item, tab, row }) => {
    const { tabPower, rowPower } = item
    if (rowPower) {
    } else {
      if (tabPower.includes(tab)) {
        return true
      } else {
        return false
      }
    }
  }

  const tableData = ref<any[]>([])
  const total = ref<number>(0)

  // const handleSelectionChange = (val) => {
  //   console.log(val, 11111111)
  // }

  const disabled = ref<boolean>(false)

  const handlerOperate = (type, row) => {
    const { id } = row
    if (type === 'edit') {
      dialogStatus.value = true
      disabled.value = true
      for (const key in ruleForm.value) {
        ruleForm.value[key] = row[key]
      }
    } else if (type === 'delete') {
      deleteData(row)
    }
  }

  const deleteData = (row) => {
    ElMessageBox.confirm('该操作将会删除该条数据, 是否继续?', {
      confirmButtonText: '确实',
      cancelButtonText: '取消',
      type: 'warning'
    }).then(() => {
      deleteAumTable({ id: row.id }).then(() => {
        message('删除成功', { type: 'success' })
        fetchData()
      })
    })
  }
  return {
    columns,
    tableData,
    total,
    disabled
    // handleSelectionChange
  }
}
