import { ref } from "vue"
import Decimal from 'decimal.js'

export function usePublicFeeColumns(feildsDisabled?) {

  const staticColumns = ref<any[]>([
    {
      feeName: '西安运营中心',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '深圳运营中心',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '上海运营中心',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '资产管理中心',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '公司',
      amount: 0,
      rowDisabled: true
    },
  ])

  const publicFeeTableData = ref<any[]>([
    {
      feeName: '西安运营中心',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '深圳运营中心',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '上海运营中心',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '资产管理中心',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '公司',
      amount: 0,
      rowDisabled: true
    },
  ])

  const amountFeildChange = (val) => {
    let sum = new Decimal(0);
    publicFeeTableData.value.forEach((el) => {
      if (el.feeName !== '公司') {
        sum = sum.plus(new Decimal(el.amount === '' ? 0 : el.amount))
      }
    })

    publicFeeTableData.value[publicFeeTableData.value.length - 1].amount = sum
  }

  const publicFeeColumns = ref<TableColumnList>([
    {
      label: '运营中心',
      prop: 'feeName',
      showOverflowTooltip: true,
    },
    {
      label: '公共费用',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <cy-amount-input v-model={row.amount} onChange={ amountFeildChange } disabled={ row.rowDisabled || feildsDisabled }></cy-amount-input>
        </>
      )
    }
  ])

  const setPublicTable = (fillObj) => {
    if (publicFeeTableData.value.length == 0) {
      publicFeeTableData.value = staticColumns.value
    }
    if (fillObj && Object.keys(fillObj).length) {
      const fillFeilds = ['xian', 'shenzhen', 'shanghai', 'asset'] // 固定值回填不包含合计
      let start = 0
      while (start < fillFeilds.length) {
        publicFeeTableData.value[start].amount = fillObj[fillFeilds[start]]
        start++
      }
      // 合计
      publicFeeTableData.value[publicFeeTableData.value.length - 1].amount = fillObj.companyAmount
    }
  }

  // 当前表格生成对对象的形式
  const genneratorPublicFee = () => {
    const res: any = {}
    const fillFeilds = ['xian', 'shenzhen', 'shanghai', 'asset']
    let start = 0
    while (start < fillFeilds.length) {
      res[fillFeilds[start]] = publicFeeTableData.value[start].amount
      start++
    }
    // 合计默认都在最后一项单独赋值
    res.companyAmount = publicFeeTableData.value[publicFeeTableData.value.length - 1].amount
    return res
  }

  return {
    publicFeeColumns,
    publicFeeTableData,
    setPublicTable,
    genneratorPublicFee
  }
}
