import { ref, computed } from 'vue'
import { useRouter } from 'vue-router'
import { forMatMoney } from '@utils'

export function useColumns(search) {
  const router = useRouter()
  const columns: TableColumnList = [
    // {
    //   type: 'selection'
    // },
    {
      label: '序号',
      type: 'index',
      width: 55
    },
    {
      label: '业务编号',
      prop: 'businessNo',
      showOverflowTooltip: true
    },
    {
      label: '客户名称',
      prop: 'customerName',
      showOverflowTooltip: true
    },
    {
      label: '授信类型',
      prop: 'contractNo',
      showOverflowTooltip: true
    },
    {
      label: '项目状态',
      prop: 'quotaDisburseBatch',
      showOverflowTooltip: true
    },
    {
      label: '授信起始日',
      prop: 'quotaDisburseBatch',
      showOverflowTooltip: true,
      width: 100
    },
    {
      label: '授信结束日',
      prop: 'quotaDisburseBatch',
      showOverflowTooltip: true,
      width: 100
    },
    {
      label: '授信币种',
      prop: 'currency',
      showOverflowTooltip: true
    },

    {
      label: '授信金额',
      prop: 'contractAmount',
      showOverflowTooltip: true,
      cellRenderer: ({ row }) => {
        return forMatMoney(row.contractAmount)
      }
    },
    {
      label: '授信是否结束',
      prop: 'quotaDisburseBatch',
      showOverflowTooltip: true,
      width: 110
    },
    {
      label: '授信期投放金额',
      prop: 'contractAmount',
      showOverflowTooltip: true,
      width: 130,
      cellRenderer: ({ row }) => {
        return forMatMoney(row.contractAmount)
      }
    },
    {
      label: '在途金额',
      prop: 'contractAmount',
      showOverflowTooltip: true,
      cellRenderer: ({ row }) => {
        return forMatMoney(row.contractAmount)
      }
    },
    {
      label: '操作',
      width: '160',
      cellRenderer: ({ index, row }) => {
        const btnList = [
          {
            msg: '明细',
            icon: 'text-customPurple iconfont icon-watch',
            power: '',
            category: 'see'
          },
          {
            msg: '修正',
            icon: 'text-customPurple iconfont icon-edit',
            power: 'modifyCustomerStandingBook',
            tabPower: ['all'],
            category: 'edit'
          }
        ]
        const options = btnList.map((item) => {
          return (
            <el-tooltip effect="dark" content={item.msg} placement="top">
              <i
                class={item.icon}
                v-power={item.power}
                onClick={() => {
                  handlerOperate(item.category, row)
                }}></i>
            </el-tooltip>
          )
        })
        return <>{options}</>
      }
    }
  ]

  const tablePower = ({ item, tab, row }) => {
    const { tabPower, rowPower } = item
    if (rowPower) {
    } else {
      if (tabPower.includes(tab)) {
        return true
      } else {
        return false
      }
    }
  }

  const tableData = ref<any[]>([])
  const total = ref<number>(0)

  const handleSelectionChange = (val) => {
    console.log(val, 11111111)
  }

  const handlerOperate = (type, row) => {
    const { id } = row
    switch (type) {
      case 'edit':
        router.push({
          path: '/customerLedgerDetails',
          query: { id, type: 'edit' }
        })
        break
      case 'see':
        router.push({
          path: '/customerLedgerDetails',
          query: { id, type: 'see' }
        })
        break
      default:
        break
    }
  }
  return {
    columns,
    tableData,
    total,
    handleSelectionChange
  }
}
