import { ref, computed } from 'vue'
import { useDictStore } from '@/store/modules/dict'

useDictStore().getConstant(['incormeExpenditureType'])
const { constant } = useDictStore()

interface TableItem {
  planDate: string
  amountType: string
  payCollType: string
  actualDate: string
  actualAmount: string
  operationDate: string
  paymentBankName: string
  paymentAccount: string
  advanceBankName: string
  advanceAccount: string
  advanceFinancingRate: string
  advanceManagementFeeRatio: string
  gmtModified: string
  isFixed: boolean
}

export function useColumns(props) {
  const { disabled } = props
  const tableData = ref<any[]>([])
  const total = ref<number>(0)

  const tablePower = (item, index) => {
    return item.power ? tableData.value.length - 1 === index : true
  }

  const columns: TableColumnList = [
    {
      label: '序号',
      type: 'index',
      width: 55
    },
    {
      label: '约定日期',
      prop: 'planDate',
      width: 160,
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <el-date-picker
            v-model={row.planDate}
            style="width: 100%"
            type="date"
            format="YYYY-MM-DD"
            value-format="YYYY-MM-DD"
            placeholder="请选择约定日期"
            disabled={row.isFixed || disabled}
          />
        )
      }
    },
    {
      label: '金额类型',
      prop: 'amountType',
      width: 150,
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        const options = constant.incormeExpenditureType.map((item) => (
          <el-option key={item.code} label={item.name} value={item.code} />
        ))
        return (
          <el-select
            v-model={row.amountType}
            placeholder="请选择金额类型"
            disabled={row.isFixed || disabled}>
            {options}
          </el-select>
        )
      }
    },
    {
      label: '收放款类型',
      prop: 'payCollType',
      width: 150,
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        const options = constant.payCollType.map((item) => (
          <el-option key={item.code} label={item.name} value={item.code} />
        ))
        return (
          <el-select
            v-model={row.payCollType}
            placeholder="请选择金额类型"
            disabled={row.isFixed || disabled}>
            {options}
          </el-select>
        )
      }
    },
    {
      label: '实收/付日期',
      prop: 'actualDate',
      width: 190,
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <el-date-picker
            v-model={row.actualDate}
            style="width: 100%"
            type="date"
            format="YYYY-MM-DD"
            value-format="YYYY-MM-DD"
            placeholder="请选择实收/付日期"
            disabled={disabled}
          />
        )
      }
    },
    {
      label: '实收/付金额',
      prop: 'actualAmount',
      width: 140,
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <cy-amount-input
            v-model={row.actualAmount}
            placeholder="请输入实收/付金额"
            disabled={disabled}
          />
        )
      }
    },
    {
      label: '操作出/入账日',
      prop: 'operationDate',
      width: 200,
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <el-date-picker
            v-model={row.operationDate}
            style="width: 100%"
            type="date"
            format="YYYY-MM-DD"
            value-format="YYYY-MM-DD"
            placeholder="请选择操作出/入账日"
            disabled={row.isFixed || disabled}
          />
        )
      }
    },
    {
      label: '实际收/放款银行名称',
      prop: 'paymentBankName',
      showOverflowTooltip: true,
      width: 200,
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <el-input
            v-model={row.paymentBankName}
            placeholder="请输入实际收/放款银行账号"
            disabled={disabled}></el-input>
        )
      }
    },
    {
      label: '实际收/放款银行账号',
      prop: 'paymentAccount',
      showOverflowTooltip: true,
      width: 180,
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <el-input
            v-model={row.paymentAccount}
            placeholder="请输入实际收/放款银行账号"
            disabled={disabled}></el-input>
        )
      }
    },
    {
      label: '垫付银行的收款账户',
      prop: 'advanceBankName',
      showOverflowTooltip: true,
      width: '160',
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <el-input
            v-model={row.advanceBankName}
            placeholder="请输入垫付银行的收款账户"
            disabled={disabled}></el-input>
        )
      }
    },
    {
      label: '垫付银行的收款账号',
      prop: 'advanceAccount',
      showOverflowTooltip: true,
      width: '160',
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <el-input
            v-model={row.advanceAccount}
            placeholder="请输入垫付银行的收款账号"
            disabled={disabled}></el-input>
        )
      }
    },
    {
      label: '融资利率（年化）%',
      prop: 'advanceFinancingRate',
      showOverflowTooltip: true,
      width: '160',
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <cy-number-input
            v-model={row.advanceFinancingRate}
            placeholder="请输入融资利率（年化）%"
            unit="%"
            disabled={disabled}
          />
        )
      }
    },
    {
      label: '管理费率（年化）%',
      prop: 'advanceManagementFeeRatio',
      showOverflowTooltip: true,
      width: '160',
      labelClassName: 'rule-required',
      cellRenderer: ({ index, row }) => {
        return (
          <cy-number-input
            v-model={row.advanceManagementFeeRatio}
            placeholder="请输入管理费率（年化）%"
            unit="%"
            disabled={disabled}
          />
        )
      }
    },
    {
      label: '更新时间',
      prop: 'gmtModified',
      showOverflowTooltip: true
    },
    {
      label: '操作',
      width: '160',
      hide: disabled,
      cellRenderer: ({ index, row }) => {
        const btnList = [
          {
            msg: '新增',
            icon: 'text-customPurple cursor-pointer',
            category: 'add',
            power: 'add'
          },
          {
            msg: '删除',
            icon: 'text-customPurple cursor-pointer',
            category: 'delete'
          }
        ]
        const options = btnList.map((item) => {
          return (
            tablePower(item, index) && (
              <span
                class={[item.icon, 'mr-[10px]']}
                onClick={() => {
                  handlerOperate(item.category, index)
                }}>
                {item.msg}
              </span>
            )
          )
        })
        return <>{options}</>
      }
    }
  ]

  const itemObj = ref<TableItem>({
    planDate: '',
    amountType: '',
    payCollType: '',
    actualDate: '',
    actualAmount: '',
    operationDate: '',
    paymentBankName: '',
    paymentAccount: '',
    advanceBankName: '',
    advanceAccount: '',
    advanceFinancingRate: '',
    advanceManagementFeeRatio: '',
    gmtModified: '',
    isFixed: false
  })

  const handlerOperate = (type, index) => {
    switch (type) {
      case 'add':
        tableData.value.push(itemObj.value)
        break
      case 'delete':
        tableData.value.splice(index, 1)
        break
      default:
        break
    }
  }
  return {
    columns,
    tableData
  }
}
