import { ref, computed } from 'vue'
import { useRouter } from 'vue-router'
import { forMatMoney } from '@utils'

export function useColumns(search, activeName) {
  const router = useRouter()
  const columns: TableColumnList = [
    // {
    //   type: 'selection',
    // },
    {
      label: '序号',
      type: 'index',
      width: 55,
    },
    {
      label: '业务编号',
      prop: 'businessNo',
      showOverflowTooltip: true
    },
    {
      label: '客户名称',
      prop: 'customerName',
      showOverflowTooltip: true
    },
    {
      label: '合同编号',
      prop: 'contractNo',
      showOverflowTooltip: true
    },
    {
      label: '支用批次',
      prop: 'quotaDisburseBatch',
      showOverflowTooltip: true
    },
    {
      label: '项目经理',
      prop: 'projectManagerName',
      showOverflowTooltip: true
    },
    {
      label: '所属部门',
      prop: 'orgName',
      showOverflowTooltip: true
    },
    {
      label: '产品类型',
      prop: 'productType',
      showOverflowTooltip: true
    },
    {
      label: '支用金额',
      prop: 'financingAmount',
      showOverflowTooltip: true,
      cellRenderer: ({ row }) => {
        return forMatMoney(row.financingAmount)
      }
    },
    {
      label: '剩余待还本金',
      prop: 'surplusPrincipal',
      showOverflowTooltip: true,
      width: '140',
      cellRenderer: ({ row }) => {
        return forMatMoney(row.surplusPrincipal)
      }
    },
    {
      label: '修正状态-财务',
      prop: 'financeModify',
      showOverflowTooltip: true,
      width: '140',
      cellRenderer: ({ row }) => {
        return row.financeModify ?  '已修正'  : '未修正'
      }
    },
    {
      label: '修正状态-再融资',
      prop: 'refinancingModify',
      showOverflowTooltip: true,
      width: '160',
      cellRenderer: ({ row }) => {
        return row.refinancingModify ?  '已修正'  : '未修正'
      }
    },
    {
      label: '操作',
      width: '160',
      cellRenderer: ({ index, row }) => {
        const btnList = [
          {
            msg: '明细',
            icon: 'text-customPurple iconfont icon-watch',
            power: '',
            tabPower: ['pending', 'all'],
            category: 'see'
          },
          {
            msg: '财务修正',
            icon: 'text-customPurple iconfont icon-edit',
            power: 'financeModify',
            tabPower: ['pending'],
            category: 'financeEdit'
          },
          {
            msg: '再融资修正',
            icon: 'text-customPurple iconfont icon-shujuxiuzheng',
            power: 'refinancingModify',
            tabPower: ['pending'],
            category: 'refinanceEdit'
          },
          {
            msg: '修正',
            icon: 'text-customPurple iconfont icon-edit',
            power: 'riskModify',
            tabPower: ['all'],
            category: 'riskEdit'
          },
        ]
        const options = btnList.map(item => {
          return tablePower({item, tab: activeName.value , row}) && (
            <el-tooltip effect='dark' content={item.msg} placement='top'>
              <i class={item.icon} v-power={ item.power } onClick={() => { handlerOperate(item.category, row) } }></i>
            </el-tooltip>
          )
        })
        return <>
         { options }
        </>
      }
    }
  ]

  const otherColumns:TableColumnList = [
    // {
    //   type: 'selection',
    // },
    {
      label: '序号',
      type: 'index',
      // width: 55,
    },
    {
      label: '收/放款类型',
      prop: 'payCollType',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => {
        return row.payCollType === 'income' ? '收款' : '放款'
      }
    },
    {
      label: '客户名称',
      prop: 'customerName',
      showOverflowTooltip: true
    },
    {
      label: '币种',
      prop: 'currency',
      showOverflowTooltip: true
    },
      {
      label: '实收/付总金额',
      prop: 'actualAmount',
      showOverflowTooltip: true
    },
    {
      label: '实收/付日期',
      prop: 'actualDate',
      showOverflowTooltip: true
    },

      {
      label: '操作',
      width: '160',
      cellRenderer: ({ index, row }) => {
        const btnList = [
          {
            msg: '明细',
            icon: 'text-customPurple iconfont icon-watch',
            power: '',
            tabPower: [],
            category: 'see'
          }
        ]
        const options = btnList.map(item => {
          return (
            <el-tooltip effect='dark' content={item.msg} placement='top' >
              <i class={item.icon} onClick={() => { handlerOperate(item.category, row) } }></i>
            </el-tooltip>
          )
        })
        return <>
         { options }
        </>
      }
    }
  ]

  const tablePower = ({ item, tab, row }) => {
    const { tabPower, rowPower } = item
    if (rowPower) {

    } else {
      if (tabPower.includes(tab)) {
        return true
      } else {
        return false
      }
    }
  }

  const tableData = ref<any[]>([])
  const total = ref<number>(0)

  const handleSelectionChange = (val) => {
    console.log(val, 11111111)
  }

  const handlerOperate = (type, row) => {
    const { id } = row
    switch (type) {
      case 'financeEdit':
        router.push({ path: '/financeEdit', query: { id }})
        break;
      case 'refinanceEdit':
        router.push({ path: '/refinanceEdit',  query: { id }})
        break;
      case 'riskEdit':
        router.push({ path: '/receiveLendingLedgerSee',  query: { type: 'riskEdit',  id }})
      break;
      case 'see':
        if (search.businessType === 'other') {
          router.push({ path: '/receiveLendingLedgerOtherSee', query: { id }})
        } else {
          router.push({ path: '/receiveLendingLedgerSee',  query: { type: 'see', id }})
        }
        break;
      default:
        break;
    }
  }
  return {
    otherColumns,
    columns,
    tableData,
    total,
    handleSelectionChange
  }
}
